This repo is under construction...

# decampy
Converts DataCamp repos to the format of https://github.com/ines/course-starter-python

Inspired by https://github.com/laderast/decampr.

Hat tip to [@marskar](https://twitter.com/marskar/status/1144256946125660165?s=20) for the name.
